pub enum Kind {
Workflows,
HistoryRows,
Panes,
Commands,
Filters,
Namespaces,
}Expand description
Which picker is open. Only used for the title, but a title that says what you are looking at is the difference between five pickers and one confusing one.
Variants
Implementations